# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so

# please check if atlas is enabled or not in numpy
# it's better to be in sync with numpy
# latest atlas (3.10.2) seems to not work correctly with scipy

%define enable_atlas 0
%{?_with_atlas: %global enable_atlas 1}
%define enable_doc 1
# disable test on build system to speed build
# but they where ok on local iurt build
%define enable_test 0

%define module	scipy

%define Werror_cflags %nil

Summary:	Scientific tools for Python
Name:		python-%{module}
Group:		Development/Python
Version:	0.17.1
Release:	%mkrel 3
License:	BSD
Url:		http://www.scipy.org

Source0:	https://github.com/scipy/scipy/releases/download/v%{version}/%{module}-%{version}.tar.xz


Obsoletes:	python-SciPy <= %{version}-%{release}
Obsoletes:	python-symeig <= %{version}%{release}
Requires:	python-numpy >= 1.7.1
Requires:	python-numpy-f2py

BuildRequires:	swig
%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif 
BuildRequires:	lapack-devel 
BuildRequires:	python-numpy-devel >= 1.9.2
BuildRequires:	python-numpy-f2py
BuildRequires:	gcc-gfortran >= 4.0
BuildRequires:	pkgconfig(netcdf)
BuildRequires:	python-nose
BuildRequires:	pkgconfig(python)
BuildRequires:	suitesparse-devel
%if %enable_doc
BuildRequires:	python-sphinx
BuildRequires:	python-sphinx_rtd_theme
BuildRequires:	python-matplotlib
BuildRequires:	texlive-dist
BuildRequires:	python-numpydoc
%endif
BuildRequires:	python-cython
BuildRequires:	python-setuptools
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools 
BuildRequires:	python3-numpy-f2py
BuildRequires:	python3-numpy-devel >= 1.9.2
BuildRequires:	python3-nose
BuildRequires:	python3-numpydoc

%description
SciPy is an open source library of scientific tools for Python. SciPy
supplements the popular numpy module, gathering a variety of high
level science and engineering modules together as a single
package. SciPy includes modules for graphics and plotting,
optimization, integration, special functions, signal and image
processing, genetic algorithms, ODE solvers, and others.

%package -n python3-scipy
Summary:	Scipy: Scientific Tools for Python
Group:		Development/Python
License:	BSD and LGPLv2+
Requires:	python3-numpy
Requires:	python3-numpy-f2py

%description -n python3-scipy
Scipy is open-source software for mathematics, science, and
engineering. The core library is NumPy which provides convenient and
fast N-dimensional array manipulation. The SciPy library is built to
work with NumPy arrays, and provides many user-friendly and efficient
numerical routines such as routines for numerical integration and
optimization. Together, they run on all popular operating systems, are
quick to install, and are free of charge. NumPy and SciPy are easy to
use, but powerful enough to be depended upon by some of the world's
leading scientists and engineers.

%if %enable_doc
%package doc
Summary:	Documentation for scipy
Group:		Development/Python
BuildArch:	noarch

%description doc
This package contains documentation for Scipy
%endif

%prep
%setup -q -n %{module}-%{version}
cat > site.cfg << EOF

[amd]
library_dirs = %{_libdir}
include_dirs = /usr/include/suitesparse
amd_libs = amd

[umfpack]
library_dirs = %{_libdir}
include_dirs = /usr/include/suitesparse
umfpack_libs = umfpack
EOF

cp -a . %{py3dir}

%build

%if %enable_atlas
%define extraflags ""
%else
%define extraflags "-DNO_ATLAS_INFO"
%endif



pushd %{py3dir}
env FFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    CFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %{__python3} setup.py config_fc --fcompiler=gnu95 --noarch build

popd

env FFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    CFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %{__python2} setup.py config_fc --fcompiler=gnu95 --noarch build


%install
# first install python3 so the binaries are overwritten by the python2 ones
pushd %{py3dir}
env FFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    CFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %{__python3} setup.py install --root=%{buildroot}

popd

env FFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    CFLAGS="%{optflags} -fPIC -O3 %extraflags" \
    ATLAS=%{_libdir}/atlas FFTW=%{_libdir} BLAS=%{_libdir} LAPACK=%{_libdir} \
    %{__python2} setup.py install --root=%{buildroot} 


# Remove doc files that should be in %%doc:
%__rm -f %{buildroot}%{python_sitearch}/%{module}/*.txt
%__rm -f %{buildroot}%{python3_sitearch}/%{module}/*.txt

%if %enable_doc
pushd doc
PYTHONPATH=%{buildroot}%{python2_sitearch}:%{python2_sitearch}:%{python2_sitelib} %__make html
popd
%endif

%if %enable_test
%check
pushd %{py3dir}
mkdir test
cd test
PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitearch} %{__python3} -c "import scipy; scipy.test('full')"
popd

mkdir test
cd test
PYTHONPATH=%{buildroot}%{python2_sitearch} %{__python2} -c "import scipy; scipy.test('full')"
%endif

%files
%doc LICENSE.txt 
%dir %{python2_sitearch}/%{module}
%{python2_sitearch}/%{module}/*
%{python2_sitearch}/%{module}-*.egg-info

%files -n python3-scipy
%doc LICENSE.txt
%{python3_sitearch}/%{module}/*
%{python3_sitearch}/*.egg-info

%if %enable_doc
%files doc
%doc doc/build/html/*
%endif


%changelog
* Thu May 26 2016 philippem <philippem> 0.17.1-3.mga6
+ Revision: 1018671
- disable test on build system to speed build but they where ok on local iurt build
- disable atlas as in numpy, enable doc and tests

* Tue May 24 2016 philippem <philippem> 0.17.1-2.mga6
+ Revision: 1018129
- rebuild without tests for arm

* Mon May 23 2016 philippem <philippem> 0.17.1-1.mga6
+ Revision: 1018037
- update to 0.17.1, disable doc, enable tests

  + joequant <joequant>
    - rebuild with new atlas and blas

  + tv <tv>
    - rebuild for new atlas

* Sun Feb 28 2016 philippem <philippem> 0.17.0-2.mga6
+ Revision: 980379
- rebuild with new python macros
- update to 0.17.0

* Thu Jan 28 2016 barjac <barjac> 0.16.1-2.mga6
+ Revision: 928439
- rebuild for arm

* Wed Oct 28 2015 joequant <joequant> 0.16.1-1.mga6
+ Revision: 895980
- upgrade to 0.16.1 and fix requires

* Thu Oct 08 2015 tv <tv> 0.16.0-4.mga6
+ Revision: 887728
- rebuild for python 3.5

* Thu Oct 08 2015 joequant <joequant> 0.16.0-3.mga6
+ Revision: 887622
- add rtd theme
- upgrade to python 3.5

* Sat Sep 19 2015 philippem <philippem> 0.16.0-2.mga6
+ Revision: 881355
- build with gcc5

* Sat Aug 08 2015 joequant <joequant> 0.16.0-1.mga6
+ Revision: 861683
- upgrade to 0.16.0

* Wed Jul 01 2015 joequant <joequant> 0.15.1-1.mga6
+ Revision: 849314
- upgrade 0.15.1

* Wed Oct 15 2014 umeabot <umeabot> 0.14.0-5.mga5
+ Revision: 743777
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.14.0-4.mga5
+ Revision: 729721
- rebuild for missing pythoneggs deps

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Tue Aug 19 2014 philippem <philippem> 0.14.0-2.mga5
+ Revision: 665621
- add doc subpackage, disable tests on BS (ok locally under iurt)

* Wed Jul 16 2014 philippem <philippem> 0.14.0-1.mga5
+ Revision: 653310
- update to 0.14.0

* Sat May 31 2014 pterjan <pterjan> 0.13.3-2.mga5
+ Revision: 629001
- Rebuild for new Python

* Fri Mar 07 2014 philippem <philippem> 0.13.3-1.mga5
+ Revision: 601063
- update to 0.13.3

* Tue Nov 19 2013 philippem <philippem> 0.13.0-4.mga4
+ Revision: 551935
- add requires on python-devel

* Wed Nov 13 2013 philippem <philippem> 0.13.0-3.mga4
+ Revision: 551061
- add missing requires

* Fri Nov 01 2013 philippem <philippem> 0.13.0-2.mga4
+ Revision: 548720
- add missing requires

* Tue Oct 29 2013 philippem <philippem> 0.13.0-1.mga4
+ Revision: 547868
- Update to 0.13.0
- Update to 0.13.0

* Tue Oct 22 2013 umeabot <umeabot> 0.12.0-5.mga4
+ Revision: 546139
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 philippem <philippem> 0.12.0-4.mga4
+ Revision: 502197
- fix dependencies

* Tue Oct 15 2013 pterjan <pterjan> 0.12.0-3.mga4
+ Revision: 499335
- Rebuild to add different pythonegg provides for python 2 and 3

  + philippem <philippem>
    - cleaning spec

* Mon Jul 01 2013 philippem <philippem> 0.12.0-1.mga4
+ Revision: 449510
- fix group, add Python 3 tests
- add python 3
- update to 0.12.0

* Fri Mar 29 2013 eatdirt <eatdirt> 0.9.0-6.mga3
+ Revision: 406070
- Remove dependence to ATLAS, fix compilation failure

* Sun Jan 13 2013 umeabot <umeabot> 0.9.0-5.mga3
+ Revision: 379476
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 barjac <barjac> 0.9.0-4.mga3
+ Revision: 334137
- rebuild for new umfpack
- spec clean

* Tue Jun 21 2011 ahmad <ahmad> 0.9.0-3.mga2
+ Revision: 110919
- Rebuild against the new umfpack lib major

* Tue May 10 2011 ahmad <ahmad> 0.9.0-2.mga1
+ Revision: 96865
- Drop old/unneeded scriptlets
- Drop the buildroot declaration
- imported package python-scipy


* Mon Feb 28 2011 Lev Givon <lev@mandriva.org> 0.9.0-1mdv2011.0
+ Revision: 641031
- Update to 0.9.0.
  Remove patches that are no longer needed.

* Wed Nov 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 0.8.0-2mdv2011.0
+ Revision: 593008
- Update for python 2.7.

* Wed Jul 28 2010 Lev Givon <lev@mandriva.org> 0.8.0-1mdv2011.0
+ Revision: 562117
- Update to 0.8.0.
  Remove old patches that are no longer necessary.
  Build documentation.

* Mon May 17 2010 Paulo Andrade <pcpa@mandriva.com.br> 0.7.2-2mdv2010.1
+ Revision: 545054
- Correct several sagemath doctest failures - upstream changeset 5790

* Thu Apr 22 2010 Lev Givon <lev@mandriva.org> 0.7.2-1mdv2010.1
+ Revision: 537983
- Update to 0.7.2.

* Tue Mar 23 2010 Lev Givon <lev@mandriva.org> 0.7.1-6mdv2010.1
+ Revision: 526950
- Byte-compile py files.

* Mon Mar 22 2010 Lev Givon <lev@mandriva.org> 0.7.1-5mdv2010.1
+ Revision: 526537
- Obsolete python-symeig (integrated into scipy 0.7.*).

* Thu Feb 04 2010 Paulo Andrade <pcpa@mandriva.com.br> 0.7.1-4mdv2010.1
+ Revision: 500968
- Rebuild

* Mon Jan 25 2010 Lev Givon <lev@mandriva.org> 0.7.1-3mdv2010.1
+ Revision: 496472
- Clean up spec file.
  Build against atlas instead of netlib blas/lapack.

* Tue Oct 06 2009 Lev Givon <lev@mandriva.org> 0.7.1-1mdv2010.0
+ Revision: 455040
- Update to 0.7.1.
- Add python-nose as an optional install dependency.

* Fri May 08 2009 Lev Givon <lev@mandriva.org> 0.7.0-2mdv2010.0
+ Revision: 373544
- Bump release - need to rebuild to run on Mandriva 2009.1.

* Thu Feb 12 2009 Lev Givon <lev@mandriva.org> 0.7.0-1mdv2009.1
+ Revision: 339808
- Update to 0.7.0.

* Mon Jul 14 2008 Funda Wang <fwang@mandriva.org> 0.6.0-8mdv2009.0
+ Revision: 234449
- rebuild for new lapack layout

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 0.6.0-7mdv2009.0
+ Revision: 222523
+ rebuild (emptylog)

* Mon Jun 16 2008 Lev Givon <lev@mandriva.org> 0.6.0-6mdv2009.0
+ Revision: 220136
- Rebuild against numpy 1.1.0.
  Disable netcdf sandbox package because it doesn't compile properly.

* Thu Jan 03 2008 Lev Givon <lev@mandriva.org> 0.6.0-5mdv2008.1
+ Revision: 141003
- Specify amd-devel and umfpack-devel versions to enable build of 0.6.0
  on 2008.0.

* Tue Jan 01 2008 Lev Givon <lev@mandriva.org> 0.6.0-4mdv2008.1
+ Revision: 140144
- Tweak buildreqs in light of the refactored suitesparse packages.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Nov 13 2007 Lev Givon <lev@mandriva.org> 0.6.0-3mdv2008.1
+ Revision: 108470
- Bump release to rebuild against lapack 3.1.1.
- Add patch to allow python-scipy to build against umfpack 5.
- Update to 0.6.0.

* Wed Aug 22 2007 Lev Givon <lev@mandriva.org> 0.5.2.1-1mdv2008.0
+ Revision: 69187
- Update to 0.5.2.1.

* Wed Jun 20 2007 Lev Givon <lev@mandriva.org> 0.5.2-6mdv2008.0
+ Revision: 41866
- Apply patches to allow 0.5.2 to build against numpy 1.0.3.

* Wed Apr 18 2007 Lev Givon <lev@mandriva.org> 0.5.2-5mdv2008.0
+ Revision: 14357
- Bump release to force build against numpy 1.0.2.


* Wed Feb 21 2007 Lev Givon <lev@mandriva.org> 0.5.2-4mdv2007.0
+ Revision: 123942
- Fix python issue in montecarlo.py
- Add netcdf-devel build dependency.
- Tweak.
- Add X11 build dependency for xplt.
- Add randomkit so that the montecarlo package can be built.
- Enable various sandbox packages.
- Add numpy install dependency.

* Thu Dec 14 2006 Lev Givon <lev@mandriva.org> 0.5.2-2mdv2007.1
+ Revision: 97096
- Add swig dependency.
- Add umfpack dependency.

* Sun Dec 10 2006 Lev Givon <lev@mandriva.org> 0.5.2-1mdv2007.1
+ Revision: 94423
- Update to version 0.5.2.
- Raise release number to permit rebuild against Python 2.5.

* Wed Nov 01 2006 Lev Givon <lev@mandriva.org> 0.5.1-2mdv2007.1
+ Revision: 75027
- Raise release number to placate build system.
- Update to 0.5.1.
- Import python-scipy

* Mon Jul 31 2006 Lev Givon <lev@mandriva.org> 0.5.0-1mdk
- Update.

* Fri May 26 2006 Lev Givon <lev@mandriva.org> 0.4.9-2mdk
- More cleanup.

* Thu May 25 2006 Lev Givon <lev@mandriva.org> 0.4.9-1mdk
- Update version.

* Mon May 22 2006 Lev Givon <lev@mandriva.org> 0.4.8-5mdk
- Make build requirements more concise.

* Sat May 06 2006 Lev Givon <lev@mandriva.org> 0.4.8-4mdk
- Correct license.

* Sat Apr 29 2006 Lev Givon <lev@mandriva.org> 0.4.8-3mdk
- Fix build requirements, build with -fPIC

* Fri Apr 28 2006 Lev Givon <lev@mandriva.org> 0.4.8-2mdk
- Patch signaltools.py bug

* Sun Mar 19 2006 Lev Givon <lev@mandriva.org> 0.4.8-1mdk
- Update version.

* Thu Feb 23 2006 Lev Givon <lev@mandriva.org> 0.4.6-1mdk
- Update version, fine-tune spec file.

* Tue Jan 31 2006 Lev Givon <lev@mandriva.org> 0.4.4-1mdk
- Update version.

* Mon Jan 23 2006 Lev Givon <lev@mandriva.org> 0.4.3-1mdk
- Package new SciPy for Mandriva.

* Fri Oct 07 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 0.3.2-3mdk
- finally build on x86_64 !

* Fri Sep 16 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 0.3.2-2mdk
- requires and use gcc3.3-g77

* Thu Mar 31 2005 Gaetan Lehmann <glehmann@n4.mandrakesoft.com> 0.3.2-1mdk
- initial contrib

